@@ -11,8 +11,8 @@ from suds.xsd.doctor import ImportDoctor, Import
 
 class API(object):
 
-    ENDPOINT = 'http://soap.secureapi.com.au/API-1.0'
-    WSDL = 'http://soap.secureapi.com.au/wsdl/API-1.0.wsdl'
+    ENDPOINT = 'http://soap.secureapi.com.au/API-1.1'
+    WSDL = 'http://soap.secureapi.com.au/wsdl/API-1.1.wsdl'
 
     def __init__(self, reseller_id, api_key, *args, **kwargs):
         self.reseller_id = reseller_id
@@ -53,9 +53,23 @@ class API(object):
             result = Decimal(re.search(r'\d+\.\d{2}', result).group())
         return result
 
+    def contact_list(self):
+        request = self.client.service.GetContactIdentifierList()
+        for identifier in request.APIResponse.ContactIdentifierList:
+            yield self.contact_info(identifier)
+
     def domain_list(self):
         request = self.client.service.GetDomainList()
-        return map(self._domain_list_item, request.APIResponse.DomainList)
+        for domain in request.APIResponse.DomainList:
+            yield self._domain_list_item(domain)
+
+    ### contact operations
+
+    def contact_info(self, identifier):
+        request = self.client.factory.create('ContactInfoRequest')
+        request.ContactIdentifier = identifier
+        response = self.client.service.ContactInfo(request)
+        return self._contact_details(response)
 
     ### domain operations
     
@@ -93,7 +107,13 @@ class API(object):
     ### private methods
     
     def _availability_item(self, o):
-    	return (o.Item, o.Available)
+        return (o.Item, o.Available)
+
+    def _contact_details(self, response):
+        c = {}
+        for k, v in response.APIResponse.ContactDetails:
+            c[k] = v
+        return c
 
     def _domain_details(self, response):
         d = {}
@@ -113,18 +133,18 @@ class API(object):
 
     def _domain_list_item(self, o):
         try:
-            expiry_date = parse(o.Expiry).date()
+            expiry_date = parse(o.Expiry[0]).date()
         except (AttributeError, TypeError):
-            expiry_date = o.Expiry
-        return (o.DomainName, o.Status, expiry_date)
+            expiry_date = o.Expiry[0]
+        return (o.DomainName[0], o.Status[0], expiry_date)
 
 
 class TestAPI(API):
 
-    ENDPOINT = 'http://soap-test.secureapi.com.au/API-1.0'
-    WSDL = 'http://soap-test.secureapi.com.au/wsdl/API-1.0.wsdl'
+    ENDPOINT = 'http://soap-test.secureapi.com.au/API-1.1'
+    WSDL = 'http://soap-test.secureapi.com.au/wsdl/API-1.1.wsdl'
 
     def spawn_domains_for_transfer(self):
         # it seems as though this method is not working properly at the server side
         response = self.client.service.SpawnDomainsForTransfer()
-        return response
\ No newline at end of file
+        return response
